{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "baseCommand": "/usr/bin/tabix",
            "arguments": [
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/tabix-cwl:1.3.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.vcf)"
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index.cwl/vcf"
                }
            ],
            "id": "#index.cwl",
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index.cwl/indexed_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "vcf merge",
            "baseCommand": [
                "/usr/bin/bcftools",
                "concat"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.3.1"
                }
            ],
            "arguments": [
                "--allow-overlaps",
                "--remove-duplicates",
                "--output-type",
                "z",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/merged.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#merge.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "merged.vcf.gz"
                    },
                    "id": "#merge.cwl/merged_vcf"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "helper.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/genome/picard-2.4.1-r:2"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "helper.pl",
                            "entry": "use File::Copy;\n\nsystem('/usr/bin/java', '-jar', '/usr/picard/picard.jar', 'IntervalListTools', @ARGV);\n\nmy $i = 1;\nfor(glob('*/scattered.interval_list')) {\n    #create unique names and relocate all the scattered intervals to a single directory\n    File::Copy::move($_, qq{$i.interval_list});\n    $i++\n}\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#split_interval_list.cwl/interval_list"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "SCATTER_COUNT=",
                        "separate": false,
                        "position": 2
                    },
                    "id": "#split_interval_list.cwl/scatter_count"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.interval_list"
                    },
                    "id": "#split_interval_list.cwl/split_interval_lists"
                }
            ],
            "id": "#split_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "mutect2 (GATK 3.6)",
            "baseCommand": [
                "/usr/local/bin/jdk1.8.0_45/bin/java",
                "-jar",
                "/usr/local/bin/GATK3.6/GenomeAnalysisTK.jar",
                "-T",
                "MuTect2"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dbmi/gatk-docker:v1"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--artifact_detection_mode",
                        "position": 7
                    },
                    "id": "#mutect.cwl/artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--cosmic",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 5
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 4
                    },
                    "id": "#mutect.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-I:normal",
                        "position": 3
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#mutect.cwl/normal_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#mutect.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I:tumor",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#mutect.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/vcf"
                }
            ],
            "id": "#mutect.cwl"
        },
        {
            "class": "Workflow",
            "label": "mutect parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#workflow.cwl/artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#workflow.cwl/normal_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#workflow.cwl/reference"
                },
                {
                    "type": "int",
                    "default": 50,
                    "id": "#workflow.cwl/scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#workflow.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl/merged_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": [
                                "#workflow.cwl/merge/merged_vcf"
                            ],
                            "id": "#workflow.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl/index"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": [
                                "#workflow.cwl/mutect/vcf"
                            ],
                            "id": "#workflow.cwl/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/merge/merged_vcf"
                    ],
                    "id": "#workflow.cwl/merge"
                },
                {
                    "scatter": "#workflow.cwl/mutect/interval_list",
                    "run": "#mutect.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/artifact_detection_mode",
                            "id": "#workflow.cwl/mutect/artifact_detection_mode"
                        },
                        {
                            "source": "#workflow.cwl/cosmic_vcf",
                            "id": "#workflow.cwl/mutect/cosmic_vcf"
                        },
                        {
                            "source": "#workflow.cwl/dbsnp_vcf",
                            "id": "#workflow.cwl/mutect/dbsnp_vcf"
                        },
                        {
                            "source": "#workflow.cwl/split_interval_list/split_interval_lists",
                            "id": "#workflow.cwl/mutect/interval_list"
                        },
                        {
                            "source": "#workflow.cwl/normal_bam",
                            "id": "#workflow.cwl/mutect/normal_bam"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/mutect/reference"
                        },
                        {
                            "source": "#workflow.cwl/tumor_bam",
                            "id": "#workflow.cwl/mutect/tumor_bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/mutect/vcf"
                    ],
                    "id": "#workflow.cwl/mutect"
                },
                {
                    "run": "#split_interval_list.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/interval_list",
                            "id": "#workflow.cwl/split_interval_list/interval_list"
                        },
                        {
                            "source": "#workflow.cwl/scatter_count",
                            "id": "#workflow.cwl/split_interval_list/scatter_count"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/split_interval_list/split_interval_lists"
                    ],
                    "id": "#workflow.cwl/split_interval_list"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/local/bin/jdk1.8.0_45/bin/java",
                "-jar",
                "/usr/local/bin/GATK3.6/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dbmi/gatk-docker:v1"
                }
            ],
            "arguments": [
                "-setKey",
                "null",
                "--filteredAreUncalled",
                "--filteredrecordsmergetype",
                "KEEP_IF_ANY_UNFILTERED",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/panel_of_normals.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 4
                    },
                    "id": "#combine_variants.cwl/interval_list"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minimumN",
                        "position": 3
                    },
                    "id": "#combine_variants.cwl/minimumN"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#combine_variants.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "panel_of_normals.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#combine_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "panel of normals workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "id": "#main/artifact_detection_mode"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/cosmic_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": "int",
                    "default": 2,
                    "id": "#main/minimumN"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "int",
                    "default": 50,
                    "id": "#main/scatter_count"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/tumor_bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/combine_variants/combined_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pon_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#combine_variants.cwl",
                    "in": [
                        {
                            "source": "#main/interval_list",
                            "id": "#main/combine_variants/interval_list"
                        },
                        {
                            "source": "#main/minimumN",
                            "id": "#main/combine_variants/minimumN"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine_variants/reference"
                        },
                        {
                            "source": [
                                "#main/mutect/merged_vcf"
                            ],
                            "id": "#main/combine_variants/vcfs"
                        }
                    ],
                    "out": [
                        "#main/combine_variants/combined_vcf"
                    ],
                    "id": "#main/combine_variants"
                },
                {
                    "scatter": "#main/mutect/tumor_bam",
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#main/artifact_detection_mode",
                            "id": "#main/mutect/artifact_detection_mode"
                        },
                        {
                            "source": "#main/cosmic_vcf",
                            "id": "#main/mutect/cosmic_vcf"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/mutect/dbsnp_vcf"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/mutect/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/mutect/reference"
                        },
                        {
                            "source": "#main/scatter_count",
                            "id": "#main/mutect/scatter_count"
                        },
                        {
                            "source": "#main/tumor_bams",
                            "id": "#main/mutect/tumor_bam"
                        }
                    ],
                    "out": [
                        "#main/mutect/merged_vcf"
                    ],
                    "id": "#main/mutect"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
